@@ -230,6 +230,16 @@ def _rosdep_main(args):
                            "that are found to be catkin packages anywhere in "
                            "the ROS_PACKAGE_PATH or in any of the directories "
                            "given by the --from-paths option.")
+    parser.add_option("--skip-keys",
+                      dest='skip_keys', action="append", default=[],
+                      help="Affects the 'check' and 'install' verbs. The "
+                           "specified rosdep keys will be ignored, i.e. not "
+                           "resolved and not installed. The option can be supplied multiple "
+                           "times. A space separated list of rosdep keys can also "
+                           "be passed as a string. A more permanent solution to "
+                           "locally ignore a rosdep key is creating a local rosdep rule "
+                           "with an empty list of packages (include it in "
+                           "/etc/ros/rosdep/sources.list.d/ before the defaults).")
     parser.add_option("--from-paths", dest='from_paths',
                       default=False, action="store_true",
                       help="Affects the 'check', 'keys', and 'install' verbs. "
@@ -246,6 +256,9 @@ def _rosdep_main(args):
         print(__version__)
         sys.exit(0)
 
+    # flatten list of skipped keys
+    options.skip_keys = [key for s in options.skip_keys for key in s.split(' ')]
+
     if len(args) == 0:
         parser.error("Please enter a command")
     command = args[0]
@@ -342,6 +355,12 @@ def _package_args_handler(command, parser, options, args):
 
     lookup = _get_default_RosdepLookup(options)
 
+    # Handle the --skip-keys option by pretending that they are packages in the catkin workspace
+    if command in ['install', 'check'] and options.skip_keys:
+        if options.verbose:
+            print("Skipping the specified rosdep keys:\n- " + '\n- '.join(options.skip_keys))
+        lookup.skipped_keys = options.skip_keys
+
     if 0 and not packages:  # disable, let individual handlers specify behavior
         # possible with empty stacks
         print("No packages in arguments, aborting")
@@ -486,7 +505,7 @@ def command_check(lookup, packages, options):
             if isinstance(ex, rospkg.ResourceNotFound):
                 print("ERROR[%s]: resource not found [%s]"%(package_name, ex.args[0]), file=sys.stderr)
             else:
-                print("ERROR[%s]: %s"%(package_name, str(ex)), file=sys.stderr)                
+                print("ERROR[%s]: %s"%(package_name, ex), file=sys.stderr)                
     if uninstalled:
         return 1
     else:
